Round with round_half_away_from_zero() and format with a fixed number of
decimal places. Decimal ties round half away from zero, and values that
round to zero display as positive zero (for example, "0.0" rather than
"-0.0").
Arguments
- x
A numeric vector.
- digits
A non-negative, integer-valued scalar giving the number of decimal places.
- width
NULL, or a non-negative, integer-valued scalar giving the minimum field width passed tobase::formatC(). The default,NULL, does not set a minimum width.